#!/bin/bash
##################################################
#Installation of pwsync fixpack for 5.1.2
#Prerequisites: Copy the zip file to the 
#build directory eg:  
##################################################
idsdir="IDS"
sundir="SunOne"
tempdir="temp"
backupdir="backup"
idsjvmdir="IDS/_jvm"
sunjvmdir="SunOne/_jvm"
tempjvmdir="temp/_jvm"
backupidsdir="backup/IDS"
backupsundir="backup/SunOne"
backupjvmdir="backup/_jvm"
zipball="IDI512Sol.tar.gz"
tarball="IDI512Sol.tar"
newjvm="sunjre131_10.bin"
readme="5.1.2-IDI-FP01_Plugins_Sol.README"
##################################################
#Check if the zip file exists
##################################################
if [ ! -f $zipball ]; then
	echo Error: $zipball not in this directory.
	echo Please copy $zipball to this directory.
	exit 1
fi

##################################################
#Clean up all the previous directories		 #	
#						 #
##################################################
if [ -d $tempdir ]; then
	rm -rf "$tempdir" 
	echo **cleanup of $tempdir directory done
fi

if [ -d $backupdir ]; then
	rm -rf "$backupdir"
	echo **cleanup of $backupdir directory done
fi

##################################################
#Creating Temp and Backup directories		 #
##################################################
echo **Creating temp, Backup directories
mkdir $tempdir 
mkdir $backupdir 
mkdir $backupidsdir 
mkdir $backupsundir
mkdir $tempjvmdir

##################################################
#Untar all the files to temp directory
##################################################
echo Untar every file to the temp dir
cp "$zipball" $tempdir
cd $tempdir
	gunzip $zipball
	if [ $? -ne 0 ]; then
		echo Please install gunzip
		exit 2
	fi
	tar -xvf $tarball
	if [ -f $newjvm ]; then
		echo Installing the jvmpack
		mv $newjvm _jvm 
		cd _jvm
		chmod a+x $newjvm
		./$newjvm
	fi

cd ../..

##################################################
#Backup the previous jvm and replace with existing
##################################################
echo backing up the jvm...
if [ -d $idsdir ]; then
	echo IDS jvm is backed up
	cp -rf $idsjvmdir $backupidsdir
	echo Temp to IDS copying...
	cp -rf $tempjvmdir/ $idsdir/
	cp -rf $backupidsdir/_jvm/lib/security/java.security $idsdir/_jvm/lib/security/java.security
else 
	echo IDS not installed
fi

if [ -d $sundir ]; then
	echo Sun jvm is backed up
	cp -rf $sunjvmdir $backupsundir
	echo Temp to Sun copying...
	cp -rf $tempjvmdir $sundir
	cp -rf $backupsundir/_jvm/lib/security/java.security $sundir/_jvm/lib/security/java.security
else 
	echo Sunone not installed
fi


##################################################
#
#Check if IDS is install.If it is then backup the
#jvm and required file
##################################################

if [ -d $idsdir ]; then 
	
	echo Copy the necessary jar files to the directory
	cp -f $idsdir/_jvm/lib/ext/idipwstore.jar $backupidsdir/
	cp -f $idsdir/_jvm/lib/ext/proxy.jar $backupidsdir/
	cp -f $idsdir/_jvm/lib/ext/mqepwstore.jar $backupidsdir/
	cp -f $idsdir/_jvm/lib/ext/idipwcrypto.jar $backupidsdir/
	cp -f $idsdir/_jvm/lib/ext/ibmjsse.jar $backupidsdir/
	cp -f $idsdir/libpwsync.so $backupidsdir/	
        	
	echo Copy the necessary jar files to the directory
	cp -f $tempdir/idipwstore.jar $idsdir/_jvm/lib/ext/
	cp -f $tempdir/proxy.jar $idsdir/_jvm/lib/ext/
	cp -f $tempdir/mqepwstore.jar $idsdir/_jvm/lib/ext/
	cp -f $tempdir/idipwcrypto.jar $idsdir/_jvm/lib/ext/
	cp -f $tempdir/libpwsync.so $idsdir/
	cp -f $tempdir/fixpack.properties $idsdir/
	cp -f $tempdir/ibmjsse.jar $idsdir/_jvm/lib/ext/	
	cp -f $tempdir/$readme $idsdir
        chmod a+rw $idsdir/_jvm/lib/ext/*.jar
	chmod a+rw $idsdir/libpwsync.so 	
else
	echo IDS not installed hence not updated 
fi


if [ -d $sundir ]; then
	

	echo add the files necessary to SUNONE
	cp -f $sundir/_jvm/lib/ext/idipwstore.jar $backupsundir/
	cp -f $sundir/_jvm/lib/ext/proxy.jar $backupsundir/
	cp -f $sundir/_jvm/lib/ext/mqepwstore.jar $backupsundir/
	cp -f $sundir/_jvm/lib/ext/idipwcrypto.jar $backupsundir/
	cp -f $sundir/_jvm/lib/ext/ibmjsse.jar $backupsundir/
	cp -f $sundir/libsunpwsync.so $backupsundir/	

	echo add the files necessary to SUNONE
	cp -f $tempdir/idipwstore.jar $sundir/_jvm/lib/ext/
	cp -f $tempdir/proxy.jar $sundir/_jvm/lib/ext/
	cp -f $tempdir/mqepwstore.jar $sundir/_jvm/lib/ext/
	cp -f $tempdir/idipwcrypto.jar $sundir/_jvm/lib/ext/
	cp -f $tempdir/ibmjsse.jar $sundir/_jvm/lib/ext/
	cp -f $tempdir/libsunpwsync.so $sundir/
	cp -f $tempdir/fixpack.properties $sundir/	
	cp -f $tempdir/$readme $sundir/
	chmod a+rw $sundir/libsunpwsync.so
	chmod a+rw $sundir/_jvm/lib/ext/*.jar 	
else 
	echo SunOne does not exist
fi
########################################################
# Delete unwanted stuff
########################################################
echo Removing $tempdir
rm -rf $tempdir
if [ -d $idsdir ]; then
	rm $idsdir/_jvm/$newjvm
fi
if [ -d $sundir ]; then
	rm $sundir/_jvm/$newjvm
fi 

